@@ -41,6 +41,7 @@ from tpot.config.regressor_sparse import regressor_config_sparse
 from tpot.config.classifier_sparse import classifier_config_sparse
 
 import numpy as np
+import pandas as pd
 from scipy import sparse
 import inspect
 import random
@@ -82,11 +83,25 @@ mnist_data = load_digits()
 training_features, testing_features, training_target, testing_target = \
     train_test_split(mnist_data.data.astype(np.float64), mnist_data.target.astype(np.float64), random_state=42)
 
+# Set up test data with missing value
+features_with_nan = np.copy(training_features)
+features_with_nan[0][0] = float('nan')
+
 # Set up the Boston data set for testing
 boston_data = load_boston()
 training_features_r, testing_features_r, training_target_r, testing_target_r = \
     train_test_split(boston_data.data, boston_data.target, random_state=42)
 
+# Set up pandas DataFrame for testing
+
+input_data = pd.read_csv(
+    'tests/tests.csv',
+    sep=',',
+    dtype=np.float64,
+)
+pd_features = input_data.drop('class', axis=1)
+pd_target = input_data['class']
+
 # Set up the sparse matrix for testing
 sparse_features = sparse.csr_matrix(training_features)
 sparse_target = training_target
@@ -747,6 +762,23 @@ def test_fit_4():
     assert not (tpot_obj._start_datetime is None)
 
 
+def test_fit_5():
+    """Assert that the TPOT fit function provides an optimized pipeline with pandas DataFrame"""
+    tpot_obj = TPOTClassifier(
+        random_state=42,
+        population_size=1,
+        offspring_size=2,
+        generations=1,
+        verbosity=0
+    )
+
+    tpot_obj.fit(pd_features, pd_target)
+
+    assert isinstance(pd_features, pd.DataFrame)
+    assert isinstance(tpot_obj._optimized_pipeline, creator.Individual)
+    assert not (tpot_obj._start_datetime is None)
+
+
 def test_memory():
     """Assert that the TPOT fit function runs normally with memory=\'auto\'."""
     tpot_obj = TPOTClassifier(
@@ -1425,8 +1457,6 @@ def test_imputer():
         verbosity=0,
         config_dict='TPOT light'
     )
-    features_with_nan = np.copy(training_features)
-    features_with_nan[0][0] = float('nan')
 
     tpot_obj.fit(features_with_nan, training_target)
 
@@ -1441,11 +1471,12 @@ def test_imputer_2():
         verbosity=0,
         config_dict='TPOT light'
     )
-    features_with_nan = np.copy(training_features)
-    features_with_nan[0][0] = float('nan')
 
-    tpot_obj.fit(features_with_nan, training_target)
+    tpot_obj.fit(training_features, training_target)
+    assert_equal(tpot_obj._fitted_imputer, None)
     tpot_obj.predict(features_with_nan)
+    assert_not_equal(tpot_obj._fitted_imputer, None)
+
 
 
 def test_imputer_3():
@@ -1458,8 +1489,7 @@ def test_imputer_3():
         verbosity=2,
         config_dict='TPOT light'
     )
-    features_with_nan = np.copy(training_features)
-    features_with_nan[0][0] = float('nan')
+
     with captured_output() as (out, err):
         imputed_features = tpot_obj._impute_values(features_with_nan)
         assert_in("Imputing missing values in feature set", out.getvalue())
@@ -1467,6 +1497,23 @@ def test_imputer_3():
     assert_not_equal(imputed_features[0][0], float('nan'))
 
 
+def test_imputer_4():
+    """Assert that the TPOT score function will not raise a ValueError in a dataset where NaNs are present."""
+    tpot_obj = TPOTClassifier(
+        random_state=42,
+        population_size=1,
+        offspring_size=2,
+        generations=1,
+        verbosity=0,
+        config_dict='TPOT light'
+    )
+
+    tpot_obj.fit(training_features, training_target)
+    assert_equal(tpot_obj._fitted_imputer, None)
+    tpot_obj.score(features_with_nan, training_target)
+    assert_not_equal(tpot_obj._fitted_imputer, None)
+
+
 def test_sparse_matrix():
     """Assert that the TPOT fit function will raise a ValueError in a sparse matrix with config_dict='TPOT light'."""
     tpot_obj = TPOTClassifier(
