@@ -24,8 +24,7 @@ License along with TPOT. If not, see <http://www.gnu.org/licenses/>.
 """
 
 import numpy as np
-from sklearn.base import ClassifierMixin
-from sklearn.base import RegressorMixin
+from sklearn.base import BaseEstimator, ClassifierMixin, RegressorMixin, TransformerMixin
 import inspect
 
 
@@ -36,7 +35,6 @@ class Operator(object):
     import_hash = None
     sklearn_class = None
     arg_types = None
-    dep_op_list = {}  # the estimator or score_func as params in this operators
 
 
 class ARGType(object):
@@ -156,7 +154,8 @@ def TPOTOperatorClassFactory(opsourse, opdict, BaseClass=Operator, ArgBaseClass=
 
     """
     class_profile = {}
-    dep_op_list = {}
+    dep_op_list = {} # list of nested estimator/callable function
+    dep_op_type = {} # type of nested estimator/callable function
     import_str, op_str, op_obj = source_decode(opsourse)
 
     if not op_obj:
@@ -197,6 +196,7 @@ def TPOTOperatorClassFactory(opsourse, opdict, BaseClass=Operator, ArgBaseClass=
                     else:
                         import_hash[dep_import_str] = [dep_op_str]
                     dep_op_list[pname] = dep_op_str
+                    dep_op_type[pname] = dep_op_obj
                     if dval:
                         for dpname in sorted(dval.keys()):
                             dprange = dval[dpname]
@@ -205,6 +205,7 @@ def TPOTOperatorClassFactory(opsourse, opdict, BaseClass=Operator, ArgBaseClass=
         class_profile['arg_types'] = tuple(arg_types)
         class_profile['import_hash'] = import_hash
         class_profile['dep_op_list'] = dep_op_list
+        class_profile['dep_op_type'] = dep_op_type
 
         @classmethod
         def parameter_types(cls):
@@ -265,10 +266,14 @@ def TPOTOperatorClassFactory(opsourse, opdict, BaseClass=Operator, ArgBaseClass=
                 # To make sure the inital operators is the first parameter just
                 # for better persentation
                 for dep_op_pname, dep_op_str in dep_op_list.items():
-                    if dep_op_pname == 'score_func':
-                        arg_value = dep_op_str
-                    else:
-                        arg_value = "{}({})".format(dep_op_str, ", ".join(dep_op_arguments[dep_op_str]))
+                    arg_value = dep_op_str # a callable function, e.g scoring function
+                    doptype = dep_op_type[dep_op_pname]
+                    if inspect.isclass(doptype): # a estimator
+                        if issubclass(doptype, BaseEstimator) or \
+                            issubclass(doptype, ClassifierMixin) or \
+                            issubclass(doptype, RegressorMixin) or \
+                            issubclass(doptype, TransformerMixin):
+                            arg_value = "{}({})".format(dep_op_str, ", ".join(dep_op_arguments[dep_op_str]))
                     tmp_op_args.append("{}={}".format(dep_op_pname, arg_value))
             op_arguments = tmp_op_args + op_arguments
             return "{}({})".format(op_obj.__name__, ", ".join(op_arguments))
